#
#  cryst_func.tcl -- Generic crystallography program support functions.
#
#  Written by William Lavender.
#
#------------------------------------------------------------------------
#
#  Copyright 1999 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

proc create_message_log_window { label } {

	set window .message_log

        #
        #  Create the window.
        #

        iwidgets::scrolledtext $window -labeltext "Message Log"

        $window configure -visibleitems 40x10
        $window configure -hscrollmode dynamic
        $window configure -vscrollmode dynamic

        pack $window -expand yes -fill both

        #
        #  Install handlers to redirect the output of mx_info(), mx_error()
        #  and MX_DEBUG() to this window.
        #

        Mx::install_output_handlers $window

	Mx::install_dialog_handler

	log_puts "*** $label Initializing ***"
}

proc log_puts { message } {
	set textwindow [ .message_log childsite ]

	$textwindow configure -state normal

	.message_log insert end "$message\n"

	$textwindow configure -state disabled

	.message_log yview moveto 1.0
}

proc energy_from_lambda { lambda } {

	set status [ catch { expr 12398.5 / $lambda } energy ]

	if { $status != 0 } {
		set energy [ expr 1.0e308 ]
	}
	return $energy
}

proc lambda_from_energy { energy } {

	set status [ catch { expr 12398.5 / $energy } lambda ]

	if { $status != 0 } {
		set lambda [ expr 1.0e308 ]
	}
	return $lambda
}

proc print_window { window } {

	set id [ winfo id $window ]

	set command "printwindow $id &"

	eval exec $command
}

